/*
 * File: GLabeledRect.java
 * -----------------------
 * This class defines a compound consisting of a rectangular frame and
 * centered label.
 */

import acm.graphics.*;

/** Defines a graphical object combining a rectangle and a label */
public class GLabeledRect extends GCompound {
	
/** Creates a new GLabeledRect object */
	public GLabeledRect(double width, double height, String text) {
		frame = new GRect(width, height);
		add(frame);
		label = new GLabel(text);
		add(label);
		recenterLabel();
	}
	
/** Creates a new GLabeledRect object at a given point */
	public GLabeledRect(double x, double y,
						double width, double height, String text) {
		this(width, height, text);
		setLocation(x, y);
	}
	
/** Sets the label font */
	public void setFont(String font) {
		label.setFont(font);
		recenterLabel();
	}
	
/** Sets the text of the label */
	public void setLabel(String text) {
		label.setLabel(text);
		recenterLabel();
	}

/** Gets the text of the label */
	public String getLabel() {
		return label.getLabel();
	}

/* Recenters the label in the window */
	private void recenterLabel() {
		double x = (frame.getWidth() - label.getWidth()) / 2;
		double y = (frame.getHeight() + label.getAscent()) / 2;
		label.setLocation(x, y);
	}

/* Private instance variables */
	private GRect frame;
	private GLabel label;
}
